@@ -1,80 +1,65 @@
-/**
-  * This file is part of the KDE project
-  * Copyright (C) 2013 Valentin Rusu <kde@rusu.info>
-  *
-  * This library is free software; you can redistribute it and/or
-  * modify it under the terms of the GNU Library General Public
-  * License version 2 as published by the Free Software Foundation.
-  *
-  * This library is distributed in the hope that it will be useful,
-  * but WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * Library General Public License for more details.
-  *
-  * You should have received a copy of the GNU Library General Public License
-  * along with this library; see the file COPYING.LIB.  If not, write to
-  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2013 Valentin Rusu <kde@rusu.info>
 
-#include <QIODevice>
-#include <QFile>
-#include <QtCore/QCryptographicHash>
-#include <assert.h>
-#include <QSaveFile>
-#include <QDebug>
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
+
+#include "backendpersisthandler.h"
+#include "kwalletbackend_debug.h"
+
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <klocalizedstring.h>
+#include <QCryptographicHash>
+#include <QFile>
+#include <QIODevice>
+#include <QSaveFile>
+#include <assert.h>
 #ifdef HAVE_GPGMEPP
-#include <gpgme.h>
 #include <gpgme++/context.h>
+#include <gpgme++/data.h>
+#include <gpgme++/decryptionresult.h>
+#include <gpgme++/encryptionresult.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
-#include <gpgme++/data.h>
-#include <gpgme++/encryptionresult.h>
-#include <gpgme++/decryptionresult.h>
 #endif
-#include "backendpersisthandler.h"
-#include "kwalletbackend.h"
 #include "blowfish.h"
-#include "sha1.h"
 #include "cbc.h"
+#include "kwalletbackend.h"
+#include "sha1.h"
 
 #ifdef Q_OS_WIN
-#include <windows.h>
+#include <windows.h> // Must be included before wincrypt.h
+
 #include <wincrypt.h>
 #endif
 
 #define KWALLET_CIPHER_BLOWFISH_ECB 0 // this was the old KWALLET_CIPHER_BLOWFISH_CBC
-#define KWALLET_CIPHER_3DES_CBC     1 // unsupported
-#define KWALLET_CIPHER_GPG          2
+#define KWALLET_CIPHER_3DES_CBC 1 // unsupported
+#define KWALLET_CIPHER_GPG 2
 #define KWALLET_CIPHER_BLOWFISH_CBC 3
 
-#define KWALLET_HASH_SHA1       0
-#define KWALLET_HASH_MD5        1 // unsupported
+#define KWALLET_HASH_SHA1 0
+#define KWALLET_HASH_MD5 1 // unsupported
 #define KWALLET_HASH_PBKDF2_SHA512 2 // used when using kwallet with pam or since 4.13 version
 
 namespace KWallet
 {
-
 typedef char Digest[16];
 
 static int getRandomBlock(QByteArray &randBlock)
 {
-
-#ifdef Q_OS_WIN //krazy:exclude=cpp
+#ifdef Q_OS_WIN // krazy:exclude=cpp
 
     // Use windows crypto API to get randomness on win32
     // HACK: this should be done using qca
     HCRYPTPROV hProv;
 
-    if (!CryptAcquireContext(&hProv, NULL, NULL, PROV_RSA_FULL,
-                             CRYPT_VERIFYCONTEXT | CRYPT_SILENT)) {
-        return -1;    // couldn't get random data
+    if (!CryptAcquireContext(&hProv, NULL, NULL, PROV_RSA_FULL, CRYPT_VERIFYCONTEXT | CRYPT_SILENT)) {
+        return -1; // couldn't get random data
     }
 
-    if (!CryptGenRandom(hProv, static_cast<DWORD>(randBlock.size()),
-                        (BYTE *)randBlock.data())) {
+    if (!CryptGenRandom(hProv, static_cast<DWORD>(randBlock.size()), (BYTE *)randBlock.data())) {
         return -3; // read error
     }
 
@@ -92,7 +77,7 @@ static int getRandomBlock(QByteArray &randBlock)
             int rc = devrand.read(randBlock.data(), randBlock.size());
 
             if (rc != randBlock.size()) {
-                return -3;      // not enough data read
+                return -3; // not enough data read
             }
 
             return 0;
@@ -111,13 +96,13 @@ static int getRandomBlock(QByteArray &randBlock)
                 int rc2 = devrand.read(randBlock.data() + rc, randBlock.size());
 
                 if (rc2 < 0) {
-                    return -3;  // read error
+                    return -3; // read error
                 }
 
                 rc += rc2;
                 cnt++;
                 if (cnt > randBlock.size()) {
-                    return -4;  // reading forever?!
+                    return -4; // reading forever?!
                 }
             } while (rc < randBlock.size());
 
@@ -133,7 +118,7 @@ static int getRandomBlock(QByteArray &randBlock)
             if (devrand.open(QIODevice::ReadOnly)) {
                 int rc = devrand.read(randBlock.data(), randBlock.size());
                 if (rc != randBlock.size()) {
-                    return -3;      // not enough data read
+                    return -3; // not enough data read
                 }
                 return 0;
             }
@@ -163,21 +148,20 @@ BackendPersistHandler *BackendPersistHandler::getPersistHandler(BackendCipherTyp
 
 BackendPersistHandler *BackendPersistHandler::getPersistHandler(char magicBuf[12])
 {
-    if ((magicBuf[2] == KWALLET_CIPHER_BLOWFISH_ECB || magicBuf[2] == KWALLET_CIPHER_BLOWFISH_CBC) &&
-            (magicBuf[3] == KWALLET_HASH_SHA1 || magicBuf[3] == KWALLET_HASH_PBKDF2_SHA512)) {
+    if ((magicBuf[2] == KWALLET_CIPHER_BLOWFISH_ECB || magicBuf[2] == KWALLET_CIPHER_BLOWFISH_CBC)
+        && (magicBuf[3] == KWALLET_HASH_SHA1 || magicBuf[3] == KWALLET_HASH_PBKDF2_SHA512)) {
         bool useECBforReading = magicBuf[2] == KWALLET_CIPHER_BLOWFISH_ECB;
         if (useECBforReading) {
-            qDebug() << "this wallet uses ECB encryption. It'll be converted to CBC on next save.";
+            qCDebug(KWALLETBACKEND_LOG) << "this wallet uses ECB encryption. It'll be converted to CBC on next save.";
         }
         return new BlowfishPersistHandler(useECBforReading);
     }
 #ifdef HAVE_GPGMEPP
-    if (magicBuf[2] == KWALLET_CIPHER_GPG &&
-            magicBuf[3] == 0) {
-        return  new GpgPersistHandler;
+    if (magicBuf[2] == KWALLET_CIPHER_GPG && magicBuf[3] == 0) {
+        return new GpgPersistHandler;
     }
 #endif // HAVE_GPGMEPP
-    return nullptr;    // unknown cipher or hash
+    return nullptr; // unknown cipher or hash
 }
 
 int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WId)
@@ -185,7 +169,7 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
     assert(wb->_cipherType == BACKEND_CIPHER_BLOWFISH);
 
     if (_useECBforReading) {
-        qDebug() << "This wallet used ECB and is now saved using CBC";
+        qCDebug(KWALLETBACKEND_LOG) << "This wallet used ECB and is now saved using CBC";
         _useECBforReading = false;
     }
 
@@ -193,7 +177,7 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
     if (!wb->_useNewHash) {
         version[3] = KWALLET_HASH_SHA1;
     } else {
-        version[3] = KWALLET_HASH_PBKDF2_SHA512;//Since 4.13 we always use PBKDF2_SHA512
+        version[3] = KWALLET_HASH_PBKDF2_SHA512; // Since 4.13 we always use PBKDF2_SHA512
     }
 
     if (sf.write(version) != 4) {
@@ -251,10 +235,9 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
     // prepend and append the random data
     QByteArray wholeFile;
     long blksz = bf.blockSize();
-    long newsize = decrypted.size() +
-                   blksz            +    // encrypted block
-                   4                +    // file size
-                   20;      // size of the SHA hash
+    long newsize = decrypted.size() + blksz + // encrypted block
+        4 + // file size
+        20; // size of the SHA hash
 
     int delta = (blksz - (newsize % blksz));
     newsize += delta;
@@ -266,7 +249,7 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
         sha.reset();
         decrypted.fill(0);
         sf.cancelWriting();
-        return -3;      // Fatal error: can't get random
+        return -3; // Fatal error: can't get random
     }
 
     for (int i = 0; i < blksz; i++) {
@@ -304,7 +287,7 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
     if (rc < 0) {
         wholeFile.fill(0);
         sf.cancelWriting();
-        return -2;  // encrypt error
+        return -2; // encrypt error
     }
 
     // write the file
@@ -315,7 +298,7 @@ int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &versio
         return -4; // write error
     }
     if (!sf.commit()) {
-        qDebug() << "WARNING: wallet sync to disk failed! QSaveFile status was " << sf.errorString();
+        qCDebug(KWALLETBACKEND_LOG) << "WARNING: wallet sync to disk failed! QSaveFile status was " << sf.errorString();
         wholeFile.fill(0);
         return -4; // write error
     }
@@ -338,9 +321,10 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
     }
 
     for (size_t i = 0; i < n; ++i) {
-        Digest d, d2; // judgment day
+        Digest d;
+        Digest d2; // judgment day
         MD5Digest ba;
-        QMap<MD5Digest, QList<MD5Digest> >::iterator it;
+        QMap<MD5Digest, QList<MD5Digest>>::iterator it;
         quint32 fsz;
         if (hds.atEnd()) {
             return -43;
@@ -364,7 +348,7 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
     CipherBlockChain bf(&_bf, _useECBforReading);
     int blksz = bf.blockSize();
     if ((encrypted.size() % blksz) != 0) {
-        return -5;     // invalid file structure
+        return -5; // invalid file structure
     }
 
     bf.setKey((void *)wb->_passhash.data(), wb->_passhash.size() * 8);
@@ -379,13 +363,13 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
     if (rc < 0) {
         wb->_passhash.fill(0);
         encrypted.fill(0);
-        return -6;  // decrypt error
+        return -6; // decrypt error
     }
 
     const char *t = encrypted.data();
 
     // strip the leading data
-    t += blksz;    // one block of random data
+    t += blksz; // one block of random data
 
     // strip the file size off
     long fsize = 0;
@@ -394,15 +378,15 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
     t++;
     fsize |= (long(*t) << 16) & 0x00ff0000;
     t++;
-    fsize |= (long(*t) <<  8) & 0x0000ff00;
+    fsize |= (long(*t) << 8) & 0x0000ff00;
     t++;
     fsize |= long(*t) & 0x000000ff;
     t++;
 
     if (fsize < 0 || fsize > long(encrypted.size()) - blksz - 4) {
-        qDebug() << "fsize: " << fsize << " encrypted.size(): " << encrypted.size() << " blksz: " << blksz;
+        qCDebug(KWALLETBACKEND_LOG) << "fsize: " << fsize << " encrypted.size(): " << encrypted.size() << " blksz: " << blksz;
         encrypted.fill(0);
-        return -9;         // file structure error.
+        return -9; // file structure error.
     }
 
     // compute the hash ourself
@@ -416,7 +400,7 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
         if (testhash[i] != encrypted[sz - 20 + i]) {
             encrypted.fill(0);
             sha.reset();
-            return -8;         // hash error.
+            return -8; // hash error.
         }
     }
 
@@ -482,7 +466,7 @@ GpgME::Error initGpgME()
         GpgME::initializeLibrary();
         err = GpgME::checkEngine(GpgME::OpenPGP);
         if (err) {
-            qDebug() << "OpenPGP not supported!";
+            qCDebug(KWALLETBACKEND_LOG) << "OpenPGP not supported!";
         }
         alreadyInitialized = true;
     }
@@ -500,16 +484,23 @@ int GpgPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WI
 
     GpgME::Error err = initGpgME();
     if (err) {
-        qDebug() << "initGpgME returned " << err.code();
-        KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to save the wallet <b>%1</b>. Error code is <b>%2</b>. Please fix your system configuration, then try again.</qt>", wb->_name.toHtmlEscaped(), err.code()));
+        qCDebug(KWALLETBACKEND_LOG) << "initGpgME returned " << err.code();
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Error when attempting to initialize OpenPGP while attempting to save the wallet <b>%1</b>. Error code is <b>%2</b>. "
+                                   "Please fix your system configuration, then try again.</qt>",
+                                   wb->_name.toHtmlEscaped(),
+                                   err.code()));
         sf.cancelWriting();
         return -5;
     }
 
-    std::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
-    if (0 == ctx) {
-        qDebug() << "Cannot setup OpenPGP context!";
-        KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to save the wallet <b>%1</b>. Please fix your system configuration, then try again.</qt>"), wb->_name.toHtmlEscaped());
+    std::shared_ptr<GpgME::Context> ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
+    if (!ctx) {
+        qCDebug(KWALLETBACKEND_LOG) << "Cannot setup OpenPGP context!";
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Error when attempting to initialize OpenPGP while attempting to save the wallet <b>%1</b>. Please fix your system "
+                                   "configuration, then try again.</qt>"),
+                              wb->_name.toHtmlEscaped());
         return -6;
     }
 
@@ -555,14 +546,19 @@ int GpgPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WI
 
     GpgME::Data decryptedData(dataBuffer.data(), dataBuffer.size(), false);
     GpgME::Data encryptedData;
-    std::vector< GpgME::Key > keys;
+    std::vector<GpgME::Key> keys;
     keys.push_back(wb->_gpgKey);
-    GpgME::EncryptionResult res = ctx->encrypt(keys, decryptedData, encryptedData, GpgME::Context::None);
+    const GpgME::EncryptionResult res = ctx->encrypt(keys, decryptedData, encryptedData, GpgME::Context::None);
     if (res.error()) {
-        int gpgerr = res.error().code();
-        KMessageBox::errorWId(w, i18n("<qt>Encryption error while attempting to save the wallet <b>%1</b>. Error code is <b>%2 (%3)</b>. Please fix your system configuration, then try again. This error may occur if you are not using a full trust GPG key. Please ensure you have the secret key for the key you are using.</qt>",
-                                      wb->_name.toHtmlEscaped(), gpgerr, gpgme_strerror(gpgerr)));
-        qDebug() << "GpgME encryption error: " << res.error().code();
+        const int gpgerr = res.error().code();
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Encryption error while attempting to save the wallet <b>%1</b>. Error code is <b>%2 (%3)</b>. Please fix your system "
+                                   "configuration, then try again. This error may occur if you are not using a full trust GPG key. Please ensure you have the "
+                                   "secret key for the key you are using.</qt>",
+                                   wb->_name.toHtmlEscaped(),
+                                   gpgerr,
+                                   res.error().asString()));
+        qCDebug(KWALLETBACKEND_LOG) << "GpgME encryption error: " << gpgerr;
         sf.cancelWriting();
         return -7;
     }
@@ -570,16 +566,20 @@ int GpgPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WI
     char buffer[4096];
     ssize_t bytes = 0;
     encryptedData.seek(0, SEEK_SET);
-    while (bytes = encryptedData.read(buffer, sizeof(buffer) / sizeof(buffer[0]))) {
+    while ((bytes = encryptedData.read(buffer, sizeof(buffer) / sizeof(buffer[0]))) > 0) {
         if (sf.write(buffer, bytes) != bytes) {
-            KMessageBox::errorWId(w, i18n("<qt>File handling error while attempting to save the wallet <b>%1</b>. Error was <b>%2</b>. Please fix your system configuration, then try again.</qt>", wb->_name.toHtmlEscaped(), sf.errorString()));
+            KMessageBox::errorWId(w,
+                                  i18n("<qt>File handling error while attempting to save the wallet <b>%1</b>. Error was <b>%2</b>. Please fix your system "
+                                       "configuration, then try again.</qt>",
+                                       wb->_name.toHtmlEscaped(),
+                                       sf.errorString()));
             sf.cancelWriting();
             return -4; // write error
         }
     }
 
     if (!sf.commit()) {
-        qDebug() << "WARNING: wallet sync to disk failed! QSaveFile status was " << sf.errorString();
+        qCDebug(KWALLETBACKEND_LOG) << "WARNING: wallet sync to disk failed! QSaveFile status was " << sf.errorString();
         return -4; // write error
     }
 
@@ -590,7 +590,11 @@ int GpgPersistHandler::read(Backend *wb, QFile &sf, WId w)
 {
     GpgME::Error err = initGpgME();
     if (err) {
-        KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to open the wallet <b>%1</b>. Error code is <b>%2</b>. Please fix your system configuration, then try again.</qt>", wb->_name.toHtmlEscaped(), err.code()));
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Error when attempting to initialize OpenPGP while attempting to open the wallet <b>%1</b>. Error code is <b>%2</b>. "
+                                   "Please fix your system configuration, then try again.</qt>",
+                                   wb->_name.toHtmlEscaped(),
+                                   err.code()));
         return -1;
     }
 
@@ -601,15 +605,18 @@ int GpgPersistHandler::read(Backend *wb, QFile &sf, WId w)
     GpgME::Data encryptedData;
     char buffer[4096];
     ssize_t bytes = 0;
-    while (bytes = sf.read(buffer, sizeof(buffer) / sizeof(buffer[0]))) {
+    while ((bytes = sf.read(buffer, sizeof(buffer) / sizeof(buffer[0])))) {
         encryptedData.write(buffer, bytes);
     }
 
 retry_label:
-    std::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
-    if (0 == ctx) {
-        KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to open the wallet <b>%1</b>. Please fix your system configuration, then try again.</qt>", wb->_name.toHtmlEscaped()));
-        qDebug() << "Cannot setup OpenPGP context!";
+    std::shared_ptr<GpgME::Context> ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
+    if (nullptr == ctx) {
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Error when attempting to initialize OpenPGP while attempting to open the wallet <b>%1</b>. Please fix your system "
+                                   "configuration, then try again.</qt>",
+                                   wb->_name.toHtmlEscaped()));
+        qCDebug(KWALLETBACKEND_LOG) << "Cannot setup OpenPGP context!";
         return -1;
     }
 
@@ -617,11 +624,19 @@ retry_label:
     encryptedData.seek(0, SEEK_SET);
     GpgME::DecryptionResult res = ctx->decrypt(encryptedData, decryptedData);
     if (res.error()) {
-        qDebug() << "Error decrypting message: " << res.error().asString() << ", code " << res.error().code() << ", source " << res.error().source();
+        qCDebug(KWALLETBACKEND_LOG) << "Error decrypting message: " << res.error().asString() << ", code " << res.error().code() << ", source "
+                                    << res.error().source();
         KGuiItem btnRetry(i18n("Retry"));
-        // FIXME the logic here should be a little more elaborate; a dialog box should be used with "retry", "cancel", but also "troubleshoot" with options to show card status and to kill scdaemon
-        int userChoice = KMessageBox::warningYesNoWId(w, i18n("<qt>Error when attempting to decrypt the wallet <b>%1</b> using GPG. If you're using a SmartCard, please ensure it's inserted then try again.<br><br>GPG error was <b>%2</b></qt>", wb->_name.toHtmlEscaped(), res.error().asString()),
-                         i18n("kwalletd GPG backend"), btnRetry, KStandardGuiItem::cancel());
+        // FIXME the logic here should be a little more elaborate; a dialog box should be used with "retry", "cancel", but also "troubleshoot" with options to
+        // show card status and to kill scdaemon
+        int userChoice = KMessageBox::warningYesNoWId(w,
+                                                      i18n("<qt>Error when attempting to decrypt the wallet <b>%1</b> using GPG. If you're using a SmartCard, "
+                                                           "please ensure it's inserted then try again.<br><br>GPG error was <b>%2</b></qt>",
+                                                           wb->_name.toHtmlEscaped(),
+                                                           res.error().asString()),
+                                                      i18n("kwalletd GPG backend"),
+                                                      btnRetry,
+                                                      KStandardGuiItem::cancel());
         if (userChoice == KMessageBox::Yes) {
             decryptedData.seek(0, SEEK_SET);
             goto retry_label;
@@ -631,7 +646,7 @@ retry_label:
 
     decryptedData.seek(0, SEEK_SET);
     QByteArray dataBuffer;
-    while (bytes = decryptedData.read(buffer, sizeof(buffer) / sizeof(buffer[0]))) {
+    while ((bytes = decryptedData.read(buffer, sizeof(buffer) / sizeof(buffer[0])))) {
         dataBuffer.append(buffer, bytes);
     }
 
@@ -646,11 +661,10 @@ retry_label:
 
     // locate the GPG key having the ID found inside the file. This will be needed later, when writing changes to disk.
     QDataStream fileStream(&sf);
-    fileStream.unsetDevice();
-    qDebug() << "This wallet was encrypted using GPG key with ID " << keyID;
+    fileStream.setDevice(nullptr);
+    qCDebug(KWALLETBACKEND_LOG) << "This wallet was encrypted using GPG key with ID " << keyID;
 
-    ctx->setKeyListMode(GPGME_KEYLIST_MODE_LOCAL);
-    std::vector< GpgME::Key > keys;
+    ctx->setKeyListMode(GpgME::KeyListMode::Local);
     err = ctx->startKeyListing();
     while (!err) {
         GpgME::Key k = ctx->nextKey(err);
@@ -658,14 +672,18 @@ retry_label:
             break;
         }
         if (keyID == k.keyID()) {
-            qDebug() << "The key was found.";
+            qCDebug(KWALLETBACKEND_LOG) << "The key was found.";
             wb->_gpgKey = k;
             break;
         }
     }
     ctx->endKeyListing();
     if (wb->_gpgKey.isNull()) {
-        KMessageBox::errorWId(w, i18n("<qt>Error when attempting to open the wallet <b>%1</b>. The wallet was encrypted using the GPG Key ID <b>%2</b> but this key was not found on your system.</qt>", wb->_name.toHtmlEscaped(), keyID));
+        KMessageBox::errorWId(w,
+                              i18n("<qt>Error when attempting to open the wallet <b>%1</b>. The wallet was encrypted using the GPG Key ID <b>%2</b> but this "
+                                   "key was not found on your system.</qt>",
+                                   wb->_name.toHtmlEscaped(),
+                                   keyID));
         return -1;
     }
 
@@ -687,7 +705,7 @@ retry_label:
         hashStream >> folderSize;
 
         MD5Digest ba = MD5Digest(reinterpret_cast<char *>(d));
-        QMap<MD5Digest, QList<MD5Digest> >::iterator it = wb->_hashes.insert(ba, QList<MD5Digest>());
+        QMap<MD5Digest, QList<MD5Digest>>::iterator it = wb->_hashes.insert(ba, QList<MD5Digest>());
         while (folderSize--) {
             Digest d2;
             hashStream.readRawData(d2, 16);
